function make
%MAKE Makefile for FMM2Du.

% S. Engblom 2011-06-30 (mexmaci64, 7.11)
% S. Engblom 2011-04-17 (mexmaci64, 7.10)
% S. Engblom 2011-03-07 (mexa64, 7.11)
% S. Engblom 2010-09-23 (mexs64, 7.7)
% S. Engblom 20010-02-02 (mexa64, 7.8)
% S. Engblom 20010-01-12 (mexmaci)
% S. Engblom 2007-05-14 (Revision)

% Caveats:
%
% -use '-DNO_COMPLEX' for platforms where complex.h is not linked correctly,
%
% -use '-DBLASINT=size_t' for the (bad!) platforms where the 'int' in the
% declaration of BLAS subroutines is in fact a 'size_t' and sizeof(size_t) >
% sizeof(int).

s = pwd;
mx = mexext;
ver = version;

if strcmp(mx,'mexglx')
  if ~strncmp(version,'7.5',3) && ~strncmp(version,'7.8',3)
    warning(['Extension .' mexext [' tested with Matlab version(s) ' ...
                        '7.5 and 7.8 only.']]);
  end
  mex(['CFLAGS=-fPIC -fno-omit-frame-pointer -std=c99 ' ...
       '-D_GNU_SOURCE -pthread -fexceptions'], ...
      '-outdir',s,'-lmwblas',[s '/source/fmm2du.c']);
elseif strcmp(mx,'mexa64')
  if ~strncmp(version,'7.2',3) && ~strncmp(version,'7.8',3) && ~ ...
        strncmp(version,'7.11',4)
    warning(['Extension .' mexext [' tested with Matlab version(s) ' ...
                        '7.2, 7.8 and 7.11 only.']]);
  end
  if strncmp(version,'7.2',3)
    mex(['CFLAGS=-fPIC -fno-omit-frame-pointer -std=c99 ' ...
         '-D_GNU_SOURCE -pthread -fexceptions'], ...
        '-outdir',s,[s '/source/fmm2du.c']);
  elseif strncmp(version,'7.8',3)
    mex(['CFLAGS=-fPIC -fno-omit-frame-pointer -std=c99 ' ...
         '-D_GNU_SOURCE -pthread -fexceptions -DBLASINT=size_t'], ...
        '-outdir',s,'-lmwblas',[s '/source/fmm2du.c']);
  else
    mex(['CFLAGS=-fPIC -fno-omit-frame-pointer -std=c99 -O3 ' ...
         '-D_GNU_SOURCE -pthread -fexceptions -DBLASINT=size_t'], ...
        ['-L' matlabroot '/sys/os/glnxa64'], ...
        '-outdir',s,'-lmwblas',[s '/source/fmm2du.c']);
  end
elseif strcmp(mx,'mexmac')
  if ~strncmp(version,'7.0',3)
    warning(['Extension .' mexext ' tested with Matlab version(s) 7.0 only.']);
  end
  mex('CC=gcc -std=c99','-outdir',s,[s '/source/fmm2du.c']);
elseif strcmp(mx,'mexmaci')
  if ~strncmp(version,'7.8',3)
    warning(['Extension .' mexext ' tested with Matlab version(s) 7.8 only.']);
  end
  mex('CC=gcc -std=c99 -fast','-outdir',s,'-lmwblas', ...
      [s '/source/fmm2du.c']);
elseif strcmp(mx,'mexmaci64')
  if ~strncmp(version,'7.10',4) && ~strncmp(version,'7.11',4)
    warning(['Extension .' mexext ...
             ' tested with Matlab version(s) 7.10 and 7.11 only.']);
  end
  mex('CC=gcc -std=c99 -fast','-outdir',s,'-lmwblas', ...
      '-DBLASINT=size_t', ...
      [s '/source/fmm2du.c']);
elseif strcmp(mx,'mexs64')
  if ~strncmp(version,'7.7',3)
    warning(['Extension .' mexext ' tested with Matlab version(s) 7.7 only.']);
  end
  mex('-DNO_COMPLEX', ...
      '-outdir',s,[s '/source/fmm2du.c']);
elseif strcmp(mx,'mexsol')
  mex('-lcplxsupp','-DNO_COMPLEX', ...
      '-outdir',s,[s '/source/fmm2du.c']);
else
  warning('New platform. Trying default make.');
  mex('-outdir',s,[s '/source/fmm2du.c']);
end
